@@ -49,6 +49,9 @@ class Spectrum(Dataset):
   def __init__(self, axis: Data1D, data: Data1D):
     super().__init__(axis,data)
 
+  def antiBloom(self, over, width=1, reverse=False):
+    self.data.antiBloom(over, width=width, reverse=reverse)
+
   def export(self,filename):
     msw = MultiSpectrumWriter(filename)
     msw.addSpectrum(self)
@@ -78,6 +81,10 @@ class Spectrum(Dataset):
     from fepydas.constructors.Plots import SpectrumPlot
     return SpectrumPlot(self)
 
+  def toScatterPlot(self):
+    from fepydas.constructors.Plots import SpectrumScatterPlot
+    return SpectrumScatterPlot(self)
+
 class SpectrumSeries(Dataset):
   def __init__(self, axis:Data1D, keys:Data1D, data:Data2D):
     super().__init__(axis,data)
@@ -164,6 +171,9 @@ class SpectrumSeries(Dataset):
     return decomp
 
   def highDynamicRange(self, max=0.99, zmin=None):
+    if self.data.values.shape[0] == 1:
+      #nothing to do here
+      return Spectrum(deepcopy(self.axis), Data1D(self.data.values.flatten(), self.data.datatype))
     #calculate weights
     zmax = (numpy.amax(self.data.values)*max) 
     if zmin is None:
@@ -197,7 +207,7 @@ class SpectrumSeries(Dataset):
       print("mapped",idx,"to",best)
       mapped[idx]=1
 
-    return Spectrum(deepcopy(self.axis), Data2D(numpy.average(self.data.values, axis=0, weights=weights),self.data.datatype))
+    return Spectrum(deepcopy(self.axis), Data1D(numpy.average(self.data.values, axis=0, weights=weights),self.data.datatype))
 
   def integrate(self):
     return Spectrum(self.keys, self.data.integrate())
@@ -222,10 +232,21 @@ class SpectrumSeries(Dataset):
     from fepydas.constructors.Plots import SpectrumSeriesPlot
     return SpectrumSeriesPlot(self, polar=polar)
 
-
+class BinnedSpectrumSeries(SpectrumSeries):
+  def __init__(self, spectrumSeries, binner, num_bins):
+    keys = binner.createBins(spectrumSeries.keys, num_bins)
+    data, self.histogram = binner.binData(spectrumSeries.data)
+    super().__init__(deepcopy(spectrumSeries.axis),keys,data)
 
 class JoinSpectrumSeries(SpectrumSeries):
   def __init__(self, spectra, interpol=False, names=None):
+    if len(spectra)==1:
+      if names: keys = [names[0]]
+      else: keys = [0]
+      data = numpy.ndarray(shape=(1, len(spectra[0].data.values)),dtype=spectra[0].data.values.dtype)
+      data[0,:] = spectra[0].data.values
+      super().__init__(spectra[0].axis, Data1D(keys,None), Data2D(data,spectra[0].data.datatype))
+      return
     if names:
       keys = Data1D(names, NUMBER)
     else:
